<?php

/**
 *  Default Theme options
 *
 * @since x-mas 1.0.0
 *
 * @param null
 * @return array $x_mas_theme_layout
 *
 */
if ( !function_exists('x_mas_default_theme_options') ) :
    function x_mas_default_theme_options() {

        $default_theme_options = array(
            /*feature section options*/
            'x-mas-footer-copyright'=>'',
            'x-mas-blog-content'=>'',
            'x-mas-blog-meta'  =>'',      
        );

        return apply_filters( 'x_mas_default_theme_options', $default_theme_options );
    }
endif;


/**
 *  Get theme options
 *
 * @since x-mas 1.0.0
 *
 * @param null
 * @return array x_mas_theme_options
 *
 */
if ( !function_exists('x_mas_get_theme_options') ) :
    function x_mas_get_theme_options() {

        $x_mas_default_theme_options = x_mas_default_theme_options();
        

        $x_mas_get_theme_options = get_theme_mod( 'x_mas_theme_options');
        if( is_array( $x_mas_get_theme_options )){
            return array_merge( $x_mas_default_theme_options, $x_mas_get_theme_options );
        }
        else{
            return $x_mas_default_theme_options;
        }

    }
endif;

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function x_mas_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	/*adding sections for footer options*/
    $wp_customize->add_section( 'x-mas-footer-option', array(
        'priority'       => 170,
        'capability'     => 'edit_theme_options',
        'theme_supports' => '',
        'title'          => __( 'Copyright Text', 'x-mas' )
    ) );

        /*copyright*/
        $wp_customize->add_setting( 'x_mas_theme_options[x-mas-footer-copyright]', array(
            'capability'        => 'edit_theme_options',
            'default'           => __('All Right Reserved 2016', 'x-mas'),
            'sanitize_callback' => 'wp_kses_post'
        ) );
        $wp_customize->add_control( 'x-mas-footer-copyright', array(
            'label'     => __( 'Copyright Text', 'x-mas' ),
            'description' => __('Your Own Copyright Text', 'x-mas'),
            'section'   => 'x-mas-footer-option',
            'settings'  => 'x_mas_theme_options[x-mas-footer-copyright]',
            'type'      => 'text',
            'priority'  => 10
        ) ); 

    /*Blog Page Options*/
    $wp_customize->add_section( 'x-mas-blog-option', array(
        'priority'       => 170,
        'capability'     => 'edit_theme_options',
        'theme_supports' => '',
        'title'          => __( 'Blog Options', 'x-mas' )
    ) );

        /*blog post*/
        $wp_customize->add_setting( 'x_mas_theme_options[x-mas-blog-content]', array(
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'x_mas_sanitize_checkbox'
        ) );
        $wp_customize->add_control( 'x-mas-blog-content', array(
            'label'     => __( 'Show Content From Content', 'x-mas' ),
            'description' => __('Checked to show the content from Content(Full Content), otherwise Excerpt content will appeared.', 'x-mas'),
            'section'   => 'x-mas-blog-option',
            'settings'  => 'x_mas_theme_options[x-mas-blog-content]',
            'type'      => 'checkbox',
            'priority'  => 10
        ) );


        /*blog post meta show/hide */
        $wp_customize->add_setting( 'x_mas_theme_options[x-mas-blog-meta]', array(
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'x_mas_sanitize_checkbox'
        ) );
        $wp_customize->add_control( 'x-mas-blog-meta', array(
            'label'     => __( 'Show/Hide Post Meta', 'x-mas' ),
            'description' => __('Checked to show/hide the meta from blog page', 'x-mas'),
            'section'   => 'x-mas-blog-option',
            'settings'  => 'x_mas_theme_options[x-mas-blog-meta]',
            'type'      => 'checkbox',
            'priority'  => 10
        ) );  
}
add_action( 'customize_register', 'x_mas_customize_register' );


/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function x_mas_customize_preview_js() {
	wp_enqueue_script( 'x_mas_customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), '20151216', true );
}
add_action( 'customize_preview_init', 'x_mas_customize_preview_js' );
