<?php 
/**
 * Custom widgets is for social icons to display on the sidebars. 
 */

if ( ! function_exists( 'x_mas_load_widgets' ) ) :
	function x_mas_load_widgets() {
		register_widget( 'X_Mas_Social_Widget' );
}
endif;
add_action( 'widgets_init', 'x_mas_load_widgets' );

if ( ! class_exists( 'X_Mas_Social_Widget' ) ) :
	class X_Mas_Social_Widget extends WP_Widget {
		function __construct() {
			$opts = array(
				'classname'   => 'x-mas-social-icons',
				'description' => esc_html__( 'Social Menu Widget', 'x-mas' ),
			);
			parent::__construct( 'x-mas-social-icons', esc_html__( 'Social Widget', 'x-mas' ), $opts );
		}
		function widget( $args, $instance ) {

			$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

			echo $args['before_widget'];

			if ( ! empty( $title ) ) {
				echo $args['before_title'] . $title . $args['after_title'];
			}

			if(  has_nav_menu( 'social' ) ){
				        wp_nav_menu( array( 'theme_location' => 'social', 'menu_class' => 'social-menu' ) ); 
					}

			echo $args['after_widget'];

		}
		function update( $new_instance, $old_instance ) {
			$instance = $old_instance;

			$instance['title'] = sanitize_text_field( $new_instance['title'] );

			return $instance;
		}

		function form( $instance ) {

			$instance = wp_parse_args( (array) $instance, array(
				'title' => '',
			) );
			?>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'x-mas' ); ?></label>
				<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $instance['title'] ); ?>" />
			</p>

			<?php if ( ! has_nav_menu( 'social' ) ) : ?>
	        <p>
				<?php esc_html_e( 'Create social menu and assign it on social menu location.', 'x-mas' ); ?>
	        </p>
	        <?php endif; ?>
			<?php
		}
	}
endif;